==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/da.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Opgaver",
    "{actor} created calendar {calendar}" : "{actor} oprettede kalenderen {calendar}",
    "You created calendar {calendar}" : "Du oprettede kalenderen {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} sletede kalenderen {calendar}",
    "You deleted calendar {calendar}" : "Du slettede kalenderen {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} opdaterede kalenderen {calendar}",
    "You updated calendar {calendar}" : "Du opdaterede kalenderen {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delte kalenderen {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delte kalenderen {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delte kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} fjernede delingen af  {calendar} fra dig",
    "You unshared calendar {calendar} from {user}" : "Du fjernede delingen af {calendar} fra {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} fjernede delingen af {calendar} fra {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} fjernede delingen af {calendar} fra sig selv",
    "You shared calendar {calendar} with group {group}" : "Du delte kalenderen {calendar} med gruppen {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delte kalenderen {calendar} med gruppen {group}",
    "You unshared calendar {calendar} from group {group}" : "Du fjernede delingen af  {calendar} fra gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} fjernede deling af kalenderen {calendar} fra gruppen {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} oprettede begivenheden {event} i kalenderen {calendar}",
    "You created event {event} in calendar {calendar}" : "Du oprettede begivenheden {event} i kalenderen {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} slettede begivenheden {event} fra kalenderen {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du slettede begivenheden {event} fra kalenderen {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} opdaterede begivenheden {event} i kalenderen {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du opdaterede begivenheden {event} i kalenderen {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} oprettede en opgave {todo} i listen {calendar}",
    "You created todo {todo} in list {calendar}" : "Du oprettede opgaven {todo} i listen {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} slettede opgaven {todo} fra listen {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du slettede opgaven {todo} fra listen {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} opdaterede opgaven {todo} i listen {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du opdaterede opgaven {todo} i listen {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} løste opgaven {todo} i listen {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du løste opgaven {todo} i listen {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} genåbnede opgaven {todo} i listen {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du genåbnede opgaven {todo} i listen {calendar}",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> er blevet ændret",
    "A calendar <strong>event</strong> was modified" : "En kalender <strong>begivenhed</strong> er blevet ændret",
    "A calendar <strong>todo</strong> was modified" : "En kalender  <strong>opgave</strong> blev ændret",
    "Contact birthdays" : "Kontakt fødselsdag",
    "Personal" : "Personligt",
    "Contacts" : "Kontakter",
    "WebDAV" : "WebDAV",
    "Technical details" : "Tekniske detaljer",
    "Remote Address: %s" : "Fjernadresse: %s",
    "Request ID: %s" : "Forespørgsels-ID: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/da.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Opgaver",
    "Personal" : "Personligt",
    "{actor} created calendar {calendar}" : "{actor} oprettede kalenderen {calendar}",
    "You created calendar {calendar}" : "Du oprettede kalenderen {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} sletede kalenderen {calendar}",
    "You deleted calendar {calendar}" : "Du slettede kalenderen {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} opdaterede kalenderen {calendar}",
    "You updated calendar {calendar}" : "Du opdaterede kalenderen {calendar}",
    "You shared calendar {calendar} as public link" : "Du har delt kalenderen {calendar} som offentligt link",
    "You removed public link for calendar {calendar}" : "Du har fjernet det offentlige link til kalenderen {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delte kalenderen {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delte kalenderen {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delte kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} fjernede delingen af  {calendar} fra dig",
    "You unshared calendar {calendar} from {user}" : "Du fjernede delingen af {calendar} fra {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} fjernede delingen af {calendar} fra {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} fjernede delingen af {calendar} fra sig selv",
    "You shared calendar {calendar} with group {group}" : "Du delte kalenderen {calendar} med gruppen {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delte kalenderen {calendar} med gruppen {group}",
    "You unshared calendar {calendar} from group {group}" : "Du fjernede delingen af  {calendar} fra gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} fjernede deling af kalenderen {calendar} fra gruppen {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} oprettede begivenheden {event} i kalenderen {calendar}",
    "You created event {event} in calendar {calendar}" : "Du oprettede begivenheden {event} i kalenderen {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} slettede begivenheden {event} fra kalenderen {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du slettede begivenheden {event} fra kalenderen {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} opdaterede begivenheden {event} i kalenderen {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du opdaterede begivenheden {event} i kalenderen {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} oprettede en opgave {todo} i listen {calendar}",
    "You created todo {todo} in list {calendar}" : "Du oprettede opgaven {todo} i listen {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} slettede opgaven {todo} fra listen {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du slettede opgaven {todo} fra listen {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} opdaterede opgaven {todo} i listen {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du opdaterede opgaven {todo} i listen {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} løste opgaven {todo} i listen {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du løste opgaven {todo} i listen {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} genåbnede opgaven {todo} i listen {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du genåbnede opgaven {todo} i listen {calendar}",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> er blevet ændret",
    "A calendar <strong>event</strong> was modified" : "En kalender <strong>begivenhed</strong> er blevet ændret",
    "A calendar <strong>todo</strong> was modified" : "En kalender  <strong>opgave</strong> blev ændret",
    "Contact birthdays" : "Kontakt fødselsdag",
    "Invitation canceled" : "Invitation annulleret",
    "Hello %s," : "Goddag %s,",
    "Invitation updated" : "Invitation opdateret ",
    "When:" : "Hvornår:",
    "Where:" : "Hvor:",
    "Description:" : "Beskrivelse:",
    "Link:" : "Link:",
    "More options …" : "Flere indstillinger…",
    "Contacts" : "Kontakter",
    "WebDAV" : "WebDAV",
    "Technical details" : "Tekniske detaljer",
    "Remote Address: %s" : "Fjernadresse: %s",
    "Request ID: %s" : "Forespørgsels-ID: %s",
    "Calendar server" : "Kalenderserver",
    "Send invitations to attendees" : "Send invitation til deltagere",
    "Automatically generate a birthday calendar" : "Generer en fødselsdagskalender automatisk",
    "Birthday calendars will be generated by a background job." : "Fødselsdagskalendere vil blive oprettet af et job, der kører i baggrunden.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Derfor vil de ikke blive synlige med det samme efter aktivering, men vil vise sig efter noget tid.",
    "%s via %s" : "%s via %s",
    "The meeting »%s« with %s was canceled." : "Mødet »%s« med %s blev annulleret.",
    "The meeting »%s« with %s was updated." : "Mødet »%s« med %s blev opdateret.",
    "%s invited you to »%s«" : "%s inviterede dig til »%s«",
    "CalDAV server" : "CalDAV server",
    "Please make sure to properly set up the email settings above." : "Vær venligst sikker på at indstille email indstillingerne ovenover ordenligt."
},
"nplurals=2; plural=(n != 1);");
